@@ -16,13 +16,37 @@ pub const INITIAL_INDENT: &str = "* ";
 
 #[inline]
 fn can_break_word(line: &str, pos: usize) -> bool {
-    if line.starts_with("Closes: #") && pos < "Closes: ".len() {
+    // Don't break if we're not at a space
+    if !line[pos..].starts_with(' ') {
         return false;
     }
-    if line.starts_with("LP: #") && pos < "LP: ".len() {
+
+    // Check if breaking here would split "Closes: #" or "LP: #"
+    // We need to look at the context around this position
+
+    // Pattern: "Closes: #" - don't break between "Closes:" and "#"
+    // or between ":" and " #"
+    if pos >= 7 && &line[pos.saturating_sub(8)..pos] == "Closes: " && line[pos..].starts_with(" #")
+    {
+        // Don't break right after "Closes: " if followed by "#"
         return false;
     }
-    line[pos..].starts_with(' ')
+
+    // Also check if we're right after "Closes:" (before the space)
+    if pos >= 7 && line[pos.saturating_sub(7)..pos].ends_with("Closes:") {
+        return false;
+    }
+
+    // Pattern: "LP: #" - don't break between "LP:" and "#"
+    if pos >= 3 && &line[pos.saturating_sub(4)..pos] == "LP: " && line[pos..].starts_with(" #") {
+        return false;
+    }
+
+    if pos >= 3 && line[pos.saturating_sub(3)..pos].ends_with("LP:") {
+        return false;
+    }
+
+    true
 }
 
 #[cfg(test)]
@@ -45,11 +69,62 @@ mod can_break_word_tests {
 
     #[test]
     fn test_closes() {
-        assert!(!super::can_break_word("Closes: #123456", 6));
-        assert!(!super::can_break_word("Closes: #123456", 7));
-        assert!(!super::can_break_word("Closes: #123456", 8));
-        assert!(!super::can_break_word("Closes: #123456", 9));
-        assert!(super::can_break_word("Closes: #123456 foo", 15));
+        // Test "Closes: #" at the start of line
+        assert!(
+            !super::can_break_word("Closes: #123456", 6),
+            "Should not break after 'Closes:'"
+        );
+        assert!(
+            !super::can_break_word("Closes: #123456", 7),
+            "Should not break between 'Closes:' and '#'"
+        );
+        assert!(
+            super::can_break_word("Closes: #123456 foo", 15),
+            "Should break after bug number"
+        );
+
+        // Test "Closes: #" in the middle of line (the bug scenario)
+        assert!(
+            !super::can_break_word("Fix bug (Closes: #123456)", 16),
+            "Should not break after 'Closes:' in middle of line"
+        );
+        assert!(
+            !super::can_break_word("Fix bug (Closes: #123456)", 17),
+            "Should not break between 'Closes:' and '#' in middle"
+        );
+
+        // Test that we can break before "(Closes:"
+        assert!(
+            super::can_break_word("Fix bug (Closes: #123456)", 7),
+            "Should be able to break before '(Closes:'"
+        );
+    }
+
+    #[test]
+    fn test_lp() {
+        // Test "LP: #" pattern
+        assert!(
+            !super::can_break_word("LP: #123456", 2),
+            "Should not break after 'LP:'"
+        );
+        assert!(
+            !super::can_break_word("LP: #123456", 3),
+            "Should not break between 'LP:' and '#'"
+        );
+        assert!(
+            super::can_break_word("LP: #123456 foo", 11),
+            "Should break after bug number"
+        );
+
+        // Test "LP: #" in the middle of line
+        assert!(
+            !super::can_break_word("Fix bug (LP: #123456)", 12),
+            "Should not break after 'LP:' in middle of line"
+        );
+        assert!(
+            !super::can_break_word("Fix bug (LP: #123456)", 13),
+            "Should not break between 'LP:' and '#' in middle"
+        );
     }
 }
 
@@ -359,18 +434,25 @@ fn rewrap_change<'a>(change: &[&'a str], width: Option<usize>) -> Result<Vec<Cow
 
     let mut lines = vec![&change[0][prefix_len..]];
 
-    // Strip the leading indentation
-    for (lineno, line) in change[1..].iter().enumerate() {
-        if line.len() < prefix_len {
-            lines.push(&line[0..0]);
-        } else if line.strip_prefix(subsequent_indent.as_str()).is_some() {
-            lines.push(&line[initial_indent.len()..]);
+    // Strip the leading indentation from continuation lines
+    // Accept any indentation >= 0, to handle varying indentation levels
+    for line in change[1..].iter() {
+        if line.is_empty() {
+            // Empty line
+            lines.push(line);
+        } else if line.starts_with(' ') {
+            // Line with indentation - determine how much to strip
+            let line_indent = line.len() - line.trim_start_matches(' ').len();
+            if line_indent >= prefix_len {
+                // Strip the prefix indentation
+                lines.push(&line[prefix_len..]);
+            } else {
+                // Less indentation than prefix - just use the line as-is
+                lines.push(line);
+            }
         } else {
-            return Err(Error::UnexpectedIndent {
-                lineno,
-                indent: subsequent_indent.len(),
-                line: line.to_string(),
-            });
+            // No indentation - use line as-is
+            lines.push(line);
         }
     }
 
@@ -411,34 +493,56 @@ fn rewrap_change<'a>(change: &[&'a str], width: Option<usize>) -> Result<Vec<Cow
 }
 
 /// Rewrap lines from an iterator of changes
-pub fn rewrap_changes<'a>(
+///
+/// Returns a Result containing the rewrapped lines or an error if rewrapping fails.
+pub fn try_rewrap_changes<'a>(
     changes: impl Iterator<Item = &'a str>,
-) -> impl Iterator<Item = Cow<'a, str>> {
+) -> Result<Vec<Cow<'a, str>>, Error> {
     let mut change = Vec::new();
     let mut indent_len: Option<usize> = None;
     let mut ret = vec![];
     for line in changes {
         // Start of a new change
         if let Some(indent) = regex_captures!(r"^[  ]*[\+\-\*] ", line) {
-            ret.extend(rewrap_change(change.as_slice(), None).unwrap());
+            if !change.is_empty() {
+                ret.extend(rewrap_change(change.as_slice(), None)?);
+            }
             indent_len = Some(indent.len());
             change = vec![line];
-        } else if let Some(current_indent) = indent_len {
-            if line.starts_with(&" ".repeat(current_indent)) {
-                change.push(line[current_indent..].into());
-            } else {
-                ret.extend(rewrap_change(change.as_slice(), None).unwrap());
-                change = vec![line];
-            }
+        } else if let Some(_current_indent) = indent_len {
+            // Continuation line - keep full line with indentation
+            change.push(line);
         } else {
-            ret.extend(rewrap_change(change.as_slice(), None).unwrap());
+            if !change.is_empty() {
+                ret.extend(rewrap_change(change.as_slice(), None)?);
+            }
             ret.push(line.into());
+            change = vec![];
         }
     }
     if !change.is_empty() {
-        ret.extend(rewrap_change(change.as_slice(), None).unwrap());
+        ret.extend(rewrap_change(change.as_slice(), None)?);
     }
-    ret.into_iter()
+    Ok(ret)
+}
+
+/// Rewrap lines from an iterator of changes
+///
+/// # Deprecated
+///
+/// This function panics on errors. Use [`try_rewrap_changes`] instead for proper error handling.
+///
+/// # Panics
+///
+/// Panics if rewrapping fails (e.g., due to invalid formatting).
+#[deprecated(
+    since = "0.2.10",
+    note = "Use try_rewrap_changes for proper error handling"
+)]
+pub fn rewrap_changes<'a>(
+    changes: impl Iterator<Item = &'a str>,
+) -> impl Iterator<Item = Cow<'a, str>> {
+    try_rewrap_changes(changes).unwrap().into_iter()
 }
 
 #[cfg(test)]
@@ -502,3 +606,111 @@ mod rewrap_tests {
 "###.split('\n').collect::<Vec<_>>().as_slice(), None).unwrap());
     }
 }
+
+#[cfg(test)]
+mod rewrap_changes_tests {
+    use super::try_rewrap_changes;
+
+    /// Test that long unbreakable lines (e.g., URLs) don't cause errors
+    #[test]
+    fn test_long_url() {
+        let changes = vec![
+            "  * Fix bug",
+            "    https://www.example.com/this/is/a/very/long/url/that/can/not/be/broken/because/it/is/longer/than/80/characters.",
+        ];
+
+        let result = try_rewrap_changes(changes.into_iter());
+        assert!(result.is_ok(), "Should handle long URLs without error");
+
+        let lines = result.unwrap();
+        assert_eq!(
+            lines,
+            vec![
+                "  * Fix bug",
+                "    https://www.example.com/this/is/a/very/long/url/that/can/not/be/broken/because/it/is/longer/than/80/characters."
+            ]
+        );
+    }
+
+    /// Test that continuation lines have proper 4-space indentation after wrapping
+    #[test]
+    fn test_continuation_indent() {
+        let changes = vec![
+            "  * Fix blocks/blockedby of archived bugs (Closes: #XXXXXXX). Thanks to somebody who fixed it.",
+            "  * Provide informative error message when unarchive fails because the bug is not archived.",
+        ];
+
+        let result = try_rewrap_changes(changes.into_iter());
+        assert!(result.is_ok(), "Should wrap successfully");
+
+        let lines = result.unwrap();
+        assert_eq!(
+            lines,
+            vec![
+                "  * Fix blocks/blockedby of archived bugs (Closes: #XXXXXXX). Thanks to",
+                "    somebody who fixed it.",
+                "  * Provide informative error message when unarchive fails because the bug is",
+                "    not archived."
+            ]
+        );
+    }
+
+    /// Test that "Closes: #" pattern stays together when wrapping
+    #[test]
+    fn test_closes_tag_not_broken() {
+        let changes = vec![
+            "  * Fix blocks/blockedby of archived bugs and more blah blah blah bl (Closes: #XXXXXXX).",
+        ];
+
+        let result = try_rewrap_changes(changes.into_iter());
+        assert!(result.is_ok(), "Should wrap successfully");
+
+        let lines = result.unwrap();
+        assert_eq!(
+            lines,
+            vec![
+                "  * Fix blocks/blockedby of archived bugs and more blah blah blah bl",
+                "    (Closes: #XXXXXXX)."
+            ]
+        );
+    }
+
+    /// Test handling of complex nested indentation structures
+    #[test]
+    fn test_complex_nested_indentation() {
+        let changes = vec![
+            "  * Main change item",
+            "    - Sub-item with 4 spaces",
+            "      + Nested sub-item with 6 spaces",
+            "        More text in nested item",
+            "    - Another sub-item",
+        ];
+
+        let result = try_rewrap_changes(changes.into_iter());
+        assert!(result.is_ok(), "Should handle nested indentation");
+
+        let lines = result.unwrap();
+        assert_eq!(
+            lines,
+            vec![
+                "  * Main change item",
+                "    - Sub-item with 4 spaces",
+                "      + Nested sub-item with 6 spaces",
+                "        More text in nested item",
+                "    - Another sub-item",
+            ]
+        );
+    }
+
+    /// Test handling of empty lines between changes
+    #[test]
+    fn test_empty_lines() {
+        let changes = vec!["  * First change", "", "  * Second change"];
+
+        let result = try_rewrap_changes(changes.into_iter());
+        assert!(result.is_ok(), "Should handle empty lines");
+
+        let lines = result.unwrap();
+        assert_eq!(lines, vec!["  * First change", "", "  * Second change"]);
+    }
+}
